
package CDN::Edgecast::Client::auto::Administration::Element::CustomerOriginAdvancedUpdateResponse;
BEGIN {
  $CDN::Edgecast::Client::auto::Administration::Element::CustomerOriginAdvancedUpdateResponse::VERSION = '0.01.00';
}
use strict;
use warnings;

{ # BLOCK to scope variables

sub get_xmlns { 'EC:WebServices' }

__PACKAGE__->__set_name('CustomerOriginAdvancedUpdateResponse');
__PACKAGE__->__set_nillable();
__PACKAGE__->__set_minOccurs();
__PACKAGE__->__set_maxOccurs();
__PACKAGE__->__set_ref();

use base qw(
    SOAP::WSDL::XSD::Typelib::Element
    SOAP::WSDL::XSD::Typelib::ComplexType
);

our $XML_ATTRIBUTE_CLASS;
undef $XML_ATTRIBUTE_CLASS;

sub __get_attr_class {
    return $XML_ATTRIBUTE_CLASS;
}

use Class::Std::Fast::Storable constructor => 'none';
use base qw(SOAP::WSDL::XSD::Typelib::ComplexType);

Class::Std::initialize();

{ # BLOCK to scope variables

my %CustomerOriginAdvancedUpdateResult_of :ATTR(:get<CustomerOriginAdvancedUpdateResult>);

__PACKAGE__->_factory(
    [ qw(        CustomerOriginAdvancedUpdateResult

    ) ],
    {
        'CustomerOriginAdvancedUpdateResult' => \%CustomerOriginAdvancedUpdateResult_of,
    },
    {
        'CustomerOriginAdvancedUpdateResult' => 'CDN::Edgecast::Client::auto::Administration::Type::CustomerOriginInfo',
    },
    {

        'CustomerOriginAdvancedUpdateResult' => 'CustomerOriginAdvancedUpdateResult',
    }
);

} # end BLOCK






} # end of BLOCK



1;


=pod

=head1 NAME

CDN::Edgecast::Client::auto::Administration::Element::CustomerOriginAdvancedUpdateResponse

=head1 VERSION

version 0.01.00

=head1 DESCRIPTION

Perl data type class for the XML Schema defined element
CustomerOriginAdvancedUpdateResponse from the namespace EC:WebServices.







=head1 PROPERTIES

The following properties may be accessed using get_PROPERTY / set_PROPERTY
methods:

=over

=item * CustomerOriginAdvancedUpdateResult

 $element->set_CustomerOriginAdvancedUpdateResult($data);
 $element->get_CustomerOriginAdvancedUpdateResult();





=back


=head1 METHODS

=head2 new

 my $element = CDN::Edgecast::Client::auto::Administration::Element::CustomerOriginAdvancedUpdateResponse->new($data);

Constructor. The following data structure may be passed to new():

 {
   CustomerOriginAdvancedUpdateResult =>  { # CDN::Edgecast::Client::auto::Administration::Type::CustomerOriginInfo
     Id =>  $some_value, # int
     MediaTypeId =>  $some_value, # int
     DirectoryName =>  $some_value, # string
     HostHeader =>  $some_value, # string
     UseOriginShield =>  $some_value, # boolean
     HttpFullUrl =>  $some_value, # string
     HttpsFullUrl =>  $some_value, # string
     HttpLoadBalancing =>  $some_value, # string
     HttpsLoadBalancing =>  $some_value, # string
     HttpHostnames =>  { # CDN::Edgecast::Client::auto::Administration::Type::ArrayOfHostname
       Hostname =>  { # CDN::Edgecast::Client::auto::Administration::Type::Hostname
         Name =>  $some_value, # string
         IsPrimary =>  $some_value, # boolean
         Ordinal =>  $some_value, # int
       },
     },
     HttpsHostnames =>  { # CDN::Edgecast::Client::auto::Administration::Type::ArrayOfHostname
       Hostname =>  { # CDN::Edgecast::Client::auto::Administration::Type::Hostname
         Name =>  $some_value, # string
         IsPrimary =>  $some_value, # boolean
         Ordinal =>  $some_value, # int
       },
     },
     ShieldPOPs =>  { # CDN::Edgecast::Client::auto::Administration::Type::ArrayOfShieldPOP
       ShieldPOP =>  { # CDN::Edgecast::Client::auto::Administration::Type::ShieldPOP
         Name =>  $some_value, # string
         POPCode =>  $some_value, # string
         Region =>  $some_value, # string
       },
     },
   },
 },

=head1 AUTHOR

Generated by SOAP::WSDL

=cut