
package CDN::Edgecast::Client::auto::Administration::Typemap::EdgeCastWebServices;
BEGIN {
  $CDN::Edgecast::Client::auto::Administration::Typemap::EdgeCastWebServices::VERSION = '0.01.00';
}
use strict;
use warnings;

our $typemap_1 = {
               'CustomerOriginUpdateResponse/CustomerOriginUpdateResult/HttpHostnames/Hostname/Ordinal' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'CustomerOriginAdvancedGetResponse/CustomerOriginAdvancedGetResult/ShieldPOPs/ShieldPOP' => 'CDN::Edgecast::Client::auto::Administration::Type::ShieldPOP',
               'CustomerOriginAdvancedGetResponse/CustomerOriginAdvancedGetResult/HttpsFullUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginDeleteResponse/CustomerOriginDeleteResult' => 'SOAP::WSDL::XSD::Typelib::Builtin::short',
               'CustomerUsersGetResponse/CustomerUsersGetResult/CustomerUser/Zip' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerHttpSmallGet/strCustomId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginUpdateResponse/CustomerOriginUpdateResult/ShieldPOPs/ShieldPOP' => 'CDN::Edgecast::Client::auto::Administration::Type::ShieldPOP',
               'CustomerWmsGetResponse/CustomerWmsGetResult/strContentURL' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerWmsUpdate/strCustomId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerHttpLargeGet' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomerHttpLargeGet',
               'CustomerHttpLargeUpdate/strCustomId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginsAdvancedGetResponse/CustomerOriginsAdvancedGetResult/CustomerOriginInfo' => 'CDN::Edgecast::Client::auto::Administration::Type::CustomerOriginInfo',
               'CustomersGetResponse/CustomersGetResult/Customer/strContactFirstName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUserAdd/strFax' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'DeliveryRegionsGetResponse/DeliveryRegionsGetResult/DeliveryRegion/Name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUsersGetResponse/CustomerUsersGetResult/CustomerUser/Email' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUserDelete/strCustomerId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'DeliveryRegionsGetResponse/DeliveryRegionsGetResult/DeliveryRegion/Id' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'CustomerOriginUpdateResponse/CustomerOriginUpdateResult/HttpsHostnames/Hostname/Name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUsersGetResponse/CustomerUsersGetResult/CustomerUser/Id' => 'SOAP::WSDL::XSD::Typelib::Builtin::unsignedInt',
               'CustomerUserAdd/strCredential' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginsAdvancedGetResponse/CustomerOriginsAdvancedGetResult/CustomerOriginInfo/ShieldPOPs/ShieldPOP/Region' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginAdvancedGetResponse/CustomerOriginAdvancedGetResult/HttpHostnames/Hostname/Ordinal' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'CustomerGetResponse/CustomerGetResult/strContactPhone' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUsersGetResponse/CustomerUsersGetResult/CustomerUser/State' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerCnameAddResponse' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomerCnameAddResponse',
               'CustomerCnameDelete/intCustomerCnameId' => 'SOAP::WSDL::XSD::Typelib::Builtin::unsignedInt',
               'DeliveryRegionsGetResponse' => 'CDN::Edgecast::Client::auto::Administration::Element::DeliveryRegionsGetResponse',
               'CustomerUrlUpdate/strCustomerId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerHttpGet/strCustomId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerHttpSmallGetResponse/CustomerHttpSmallGetResult/strContentURL' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginDelete/strCustomId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginAdvancedUpdateResponse/CustomerOriginAdvancedUpdateResult/ShieldPOPs/ShieldPOP/POPCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUserAdd/strTimeZoneId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerCnameGet/strCustomerId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginsGetResponse/CustomerOriginsGetResult/CustomerOrigin/DiskStorageLocation' => 'SOAP::WSDL::XSD::Typelib::Builtin::short',
               'CustomerUpdate/strContactLastName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginAdvancedGetResponse' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomerOriginAdvancedGetResponse',
               'CustomerUpdate/strContactEmail' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUserUpdate/strZip' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginAdvancedGetResponse/CustomerOriginAdvancedGetResult/HostHeader' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerAdd/strContactFirstName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerGetResponse/CustomerGetResult/strHex' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginsAdvancedGetResponse/CustomerOriginsAdvancedGetResult/CustomerOriginInfo/HttpHostnames/Hostname/IsPrimary' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'CustomerUsersGetResponse/CustomerUsersGetResult/CustomerUser/Fax' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUserGetResponse/CustomerUserGetResult/IsAdmin' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'CustomerOriginGetResponse/CustomerOriginGetResult/DiskStorageLocationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerDelete' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomerDelete',
               'CustomerAdd/strBillingCity' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerCustomIdUpdate/strCustomId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUsersGetResponse/CustomerUsersGetResult/CustomerUser/TimeZoneId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'CustomerOriginUpdateResponse/CustomerOriginUpdateResult/HttpLoadBalancing' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginsGet/intMediaType' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'CustomerCnamesGetResponse/CustomerCnamesGetResult/CustomerCname/Id' => 'SOAP::WSDL::XSD::Typelib::Builtin::unsignedInt',
               'CustomersGetResponse/CustomersGetResult/Customer/strBillingAddress1' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerCnamesGetResponse/CustomerCnamesGetResult/CustomerCname' => 'CDN::Edgecast::Client::auto::Administration::Type::CustomerCname',
               'CustomerDelete/strCredential' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUrlUpdateResponse' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomerUrlUpdateResponse',
               'CustomerOriginAdvancedGetResponse/CustomerOriginAdvancedGetResult/HttpHostnames/Hostname/Name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerAccessModuleGet/strCredential' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginAdvancedUpdateResponse/CustomerOriginAdvancedUpdateResult/DirectoryName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerAdd' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomerAdd',
               'CustomerAccessModuleUpdate/strCustomerId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginAdvancedGetResponse/CustomerOriginAdvancedGetResult/HttpHostnames' => 'CDN::Edgecast::Client::auto::Administration::Type::ArrayOfHostname',
               'CustomersGetResponse/CustomersGetResult/Customer/strContactTitle' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerCustomIdUpdate' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomerCustomIdUpdate',
               'CustomerGetResponse/CustomerGetResult/strBillingAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'OriginShieldPOPsGetResponse/OriginShieldPOPsGetResult/ShieldPOP/Region' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerStatusUpdateResponse' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomerStatusUpdateResponse',
               'CustomerCnameGetResponse/CustomerCnameGetResult/OriginId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'CustomerCnameGet/strCredential' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerAccountMeasuredByUpdate/intAccountMeasuredBy' => 'SOAP::WSDL::XSD::Typelib::Builtin::short',
               'CustomerOriginAdvancedUpdate/strHttpsHostnames' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginAdvancedAdd/strHttpHostnames' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerAccessModuleUpdate/strCredential' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUserGetResponse/CustomerUserGetResult/Title' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUserGet' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomerUserGet',
               'CustomerOriginAdvancedAdd/strHttpLoadBalMode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerAdd/strBillingContactFax' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerHttpGetResponse/CustomerHttpGetResult/intStatus' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'CustomerOriginUpdate' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomerOriginUpdate',
               'CustomerOriginAdvancedGetResponse/CustomerOriginAdvancedGetResult/HttpLoadBalancing' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerHttpSmallGetResponse/CustomerHttpSmallGetResult/intStatus' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'CustomerOriginAdvancedUpdateResponse' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomerOriginAdvancedUpdateResponse',
               'CustomerHttpUpdate/strContentURL' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerAdd/strCompanyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerGetResponse/CustomerGetResult/strBillingContactTitle' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerAccessModuleUpdate/intAccessModuleId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'CustomerOriginAdvancedUpdateResponse/CustomerOriginAdvancedUpdateResult/HttpHostnames/Hostname' => 'CDN::Edgecast::Client::auto::Administration::Type::Hostname',
               'CustomerAccessModuleGetResponse/CustomerAccessModuleGetResult' => 'SOAP::WSDL::XSD::Typelib::Builtin::short',
               'CustomerOriginAdvancedUpdate/strDirName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerWmsUpdate' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomerWmsUpdate',
               'CustomerDeliveryRegionUpdate/strCustomId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomersGet/strCredential' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerStatusGet/strCustomerId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginDelete/strCredential' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginUpdateResponse/CustomerOriginUpdateResult/ShieldPOPs' => 'CDN::Edgecast::Client::auto::Administration::Type::ArrayOfShieldPOP',
               'CustomerOriginAdd/strOriginString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginAdvancedGetResponse/CustomerOriginAdvancedGetResult/MediaTypeId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'OriginShieldPOPsGet/strCustomerId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerWmsGet/strCustomId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginAdvancedUpdate/strCustomerId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUpdate/strBillingZip' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerAdd/strCity' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomersGetResponse/CustomersGetResult/Customer/strCustomId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginsAdvancedGetResponse/CustomerOriginsAdvancedGetResult/CustomerOriginInfo/HttpHostnames/Hostname/Ordinal' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'CustomerUserGet/strCustomerId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerGetResponse/CustomerGetResult/strCity' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginGetResponse/CustomerOriginGetResult' => 'CDN::Edgecast::Client::auto::Administration::Type::CustomerOrigin',
               'CustomersGetResponse/CustomersGetResult/Customer/strContactFax' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginGet' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomerOriginGet',
               'CustomersGetResponse/CustomersGetResult/Customer/strNotes' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUpdate/strBillingContactFax' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/faultstring' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerFmsUpdate/strCustomerId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginAdvancedUpdate' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomerOriginAdvancedUpdate',
               'CustomersGetResponse/CustomersGetResult/Customer/strBillingAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginAdvancedGetResponse/CustomerOriginAdvancedGetResult/HttpsHostnames/Hostname/IsPrimary' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'CustomersGetResponse/CustomersGetResult/Customer/strAddress1' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUpdateResponse/CustomerUpdateResult' => 'SOAP::WSDL::XSD::Typelib::Builtin::short',
               'CustomerUserGetResponse/CustomerUserGetResult/Email' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginsAdvancedGetResponse/CustomerOriginsAdvancedGetResult/CustomerOriginInfo/HttpsHostnames/Hostname' => 'CDN::Edgecast::Client::auto::Administration::Type::Hostname',
               'CustomerOriginAdvancedGetResponse/CustomerOriginAdvancedGetResult/DirectoryName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginUpdateResponse/CustomerOriginUpdateResult' => 'CDN::Edgecast::Client::auto::Administration::Type::CustomerOriginInfo',
               'CustomerServiceUpdate/intStatus' => 'SOAP::WSDL::XSD::Typelib::Builtin::short',
               'CustomerOriginGet/strCustomId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerAccessModuleGet/intAccessModuleId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'CustomerOriginAdvancedGetResponse/CustomerOriginAdvancedGetResult/ShieldPOPs/ShieldPOP/Name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUpdate/strContactTitle' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomersGetResponse/CustomersGetResult/Customer/strBillingCity' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerAdd/strNotes' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerAdd/strContactLastName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginAdvancedUpdateResponse/CustomerOriginAdvancedUpdateResult/ShieldPOPs/ShieldPOP/Region' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginAdvancedGetResponse/CustomerOriginAdvancedGetResult/ShieldPOPs' => 'CDN::Edgecast::Client::auto::Administration::Type::ArrayOfShieldPOP',
               'CustomerOriginsGetResponse' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomerOriginsGetResponse',
               'CustomersGetResponse/CustomersGetResult/Customer/strBillingContactTitle' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUsersGet/strCustomerId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerAddResponse/CustomerAddResult' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginGetResponse' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomerOriginGetResponse',
               'CustomerHttpSmallUpdate/strStatus' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginAdvancedUpdateResponse/CustomerOriginAdvancedUpdateResult/HttpsHostnames' => 'CDN::Edgecast::Client::auto::Administration::Type::ArrayOfHostname',
               'CustomerOriginsGet' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomerOriginsGet',
               'CustomersGetResponse/CustomersGetResult/Customer/strBillingContactLastName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomersGet' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomersGet',
               'DeliveryRegionsGet' => 'CDN::Edgecast::Client::auto::Administration::Element::DeliveryRegionsGet',
               'CustomerUrlUpdate/strUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerCnameGetResponse' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomerCnameGetResponse',
               'CustomerDeleteResponse/CustomerDeleteResult' => 'SOAP::WSDL::XSD::Typelib::Builtin::short',
               'CustomerGet/strCustomId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerCnamesGet/strCustomId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginGetResponse/CustomerOriginGetResult/Id' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'CustomerAdd/strContactFax' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerHttpSmallUpdate/strCredential' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerGetResponse/CustomerGetResult/strZip' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerCnameAdd/strCname' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUserAdd/strState' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUrlUpdate' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomerUrlUpdate',
               'CustomerFmsUpdateResponse/CustomerFmsUpdateResult' => 'SOAP::WSDL::XSD::Typelib::Builtin::short',
               'CustomerHttpSmallUpdate/strCustomerId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUpdateResponse' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomerUpdateResponse',
               'CustomersGetResponse/CustomersGetResult/Customer/strWebsite' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginAdvancedUpdate/strShieldPopCodes' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerHttpLargeGetResponse/CustomerHttpLargeGetResult/strContentURL' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginAdd/strCustomerId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerAccessModuleGet' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomerAccessModuleGet',
               'CustomerGetResponse' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomerGetResponse',
               'CustomerCnamesGetResponse/CustomerCnamesGetResult/CustomerCname/PointsTo' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomersGetResponse' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomersGetResponse',
               'CustomerStatusGet/strCredential' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerHttpSmallUpdate' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomerHttpSmallUpdate',
               'CustomerUpdate/strBillingState' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginAdvancedUpdateResponse/CustomerOriginAdvancedUpdateResult/HttpHostnames/Hostname/IsPrimary' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'CustomerUserAdd/strCountry' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerCnamesGet/strCustomerId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUsersGetResponse/CustomerUsersGetResult/CustomerUser/Address2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerAccessModuleGet/strCustomerId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerAccountMeasuredByGet/strCustomerId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUserAccessModuleUpdateResponse' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomerUserAccessModuleUpdateResponse',
               'CustomerUserGetResponse/CustomerUserGetResult/TimeZoneId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'OriginShieldPOPsGet/strCustomId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginAdvancedUpdateResponse/CustomerOriginAdvancedUpdateResult/HttpsLoadBalancing' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUrlUpdate/strDomainTypeId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginsAdvancedGetResponse/CustomerOriginsAdvancedGetResult/CustomerOriginInfo/ShieldPOPs/ShieldPOP' => 'CDN::Edgecast::Client::auto::Administration::Type::ShieldPOP',
               'CustomerAddResponse' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomerAddResponse',
               'CustomersGetResponse/CustomersGetResult/Customer/strContactEmail' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'OriginShieldPOPsGet' => 'CDN::Edgecast::Client::auto::Administration::Element::OriginShieldPOPsGet',
               'CustomerOriginAdvancedAdd/strCustomerId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUpdate/strCountry' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerGetResponse/CustomerGetResult/strContactLastName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginsAdvancedGetResponse/CustomerOriginsAdvancedGetResult/CustomerOriginInfo/HttpHostnames/Hostname' => 'CDN::Edgecast::Client::auto::Administration::Type::Hostname',
               'CustomerOriginsAdvancedGetResponse/CustomerOriginsAdvancedGetResult/CustomerOriginInfo/HttpsHostnames' => 'CDN::Edgecast::Client::auto::Administration::Type::ArrayOfHostname',
               'CustomerOriginAdvancedUpdateResponse/CustomerOriginAdvancedUpdateResult/HttpFullUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerAdd/strAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginAdvancedUpdateResponse/CustomerOriginAdvancedUpdateResult' => 'CDN::Edgecast::Client::auto::Administration::Type::CustomerOriginInfo',
               'CustomerUserGetResponse/CustomerUserGetResult/Id' => 'SOAP::WSDL::XSD::Typelib::Builtin::unsignedInt',
               'CustomerOriginUpdateResponse/CustomerOriginUpdateResult/HttpHostnames/Hostname/Name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUserAccessModuleUpdate/strCustomId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUpdate/strNotes' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginGetResponse/CustomerOriginGetResult/OriginShield' => 'SOAP::WSDL::XSD::Typelib::Builtin::short',
               'CustomerOriginAdvancedGetResponse/CustomerOriginAdvancedGetResult/Id' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'CustomerGetResponse/CustomerGetResult/strContactFax' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginAdvancedUpdate/intCustomerOriginId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'CustomerUpdate/strCompanyName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginUpdateResponse/CustomerOriginUpdateResult/ShieldPOPs/ShieldPOP/Region' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginUpdateResponse/CustomerOriginUpdateResult/HttpHostnames' => 'CDN::Edgecast::Client::auto::Administration::Type::ArrayOfHostname',
               'CustomerUserAccessModuleGet/intAccessModuleId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'CustomerOriginUpdateResponse/CustomerOriginUpdateResult/MediaTypeId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'CustomerHttpUpdate/strCustomerId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginUpdateResponse/CustomerOriginUpdateResult/DirectoryName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginAdvancedGetResponse/CustomerOriginAdvancedGetResult/HttpsHostnames/Hostname' => 'CDN::Edgecast::Client::auto::Administration::Type::Hostname',
               'CustomerGetResponse/CustomerGetResult/strBillingContactLastName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUserUpdate/strFirstName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerAdd/strBillingContactLastName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginsGet/strCustomId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerWmsUpdate/strCustomerId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerHttpSmallUpdateResponse' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomerHttpSmallUpdateResponse',
               'CustomerUsersGet/strCustomId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginAdvancedAdd/strHttpsLoadBalMode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerHttpSmallGet' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomerHttpSmallGet',
               'CustomerOriginAdvancedGetResponse/CustomerOriginAdvancedGetResult/HttpsLoadBalancing' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUserGetResponse/CustomerUserGetResult/Fax' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerCnameAdd/strCustomId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerWmsGetResponse/CustomerWmsGetResult' => 'CDN::Edgecast::Client::auto::Administration::Type::WmsInfo',
               'CustomerHttpUpdateResponse/CustomerHttpUpdateResult' => 'SOAP::WSDL::XSD::Typelib::Builtin::short',
               'CustomerOriginAdvancedGetResponse/CustomerOriginAdvancedGetResult/HttpFullUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUserDelete/strCustomId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginDelete/intCustomerOriginId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'CustomerOriginAdvancedAdd/strCredential' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginAdvancedUpdateResponse/CustomerOriginAdvancedUpdateResult/HttpHostnames/Hostname/Name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerServiceUpdate/strCustomerId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerAccountMeasuredByGetResponse' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomerAccountMeasuredByGetResponse',
               'CustomerOriginAdvancedAdd/intMediaType' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'CustomerHttpSmallUpdate/strContentURL' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUserUpdate/strCity' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginAddResponse' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomerOriginAddResponse',
               'CustomerOriginAdvancedUpdateResponse/CustomerOriginAdvancedUpdateResult/Id' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'CustomerOriginAdvancedGetResponse/CustomerOriginAdvancedGetResult' => 'CDN::Edgecast::Client::auto::Administration::Type::CustomerOriginInfo',
               'CustomerAdd/strContactEmail' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerAdd/strBillingContactEmail' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginsAdvancedGetResponse/CustomerOriginsAdvancedGetResult/CustomerOriginInfo/ShieldPOPs/ShieldPOP/POPCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerHttpLargeUpdate' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomerHttpLargeUpdate',
               'CustomerGetResponse/CustomerGetResult/intId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'CustomerUserGet/intCustomerUserId' => 'SOAP::WSDL::XSD::Typelib::Builtin::unsignedInt',
               'CustomerUserDelete/strCredential' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginAdvancedGetResponse/CustomerOriginAdvancedGetResult/ShieldPOPs/ShieldPOP/POPCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUpdate' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomerUpdate',
               'CustomerUsersGetResponse/CustomerUsersGetResult' => 'CDN::Edgecast::Client::auto::Administration::Type::CustomerUsers',
               'CustomerGetResponse/CustomerGetResult/strName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerWmsUpdateResponse' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomerWmsUpdateResponse',
               'CustomerStatusGet/strCustomId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUpdate/strContactFirstName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerHttpSmallGet/strCredential' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginAdvancedUpdateResponse/CustomerOriginAdvancedUpdateResult/ShieldPOPs/ShieldPOP' => 'CDN::Edgecast::Client::auto::Administration::Type::ShieldPOP',
               'CustomerUserAccessModuleUpdate/intStatus' => 'SOAP::WSDL::XSD::Typelib::Builtin::short',
               'CustomerOriginUpdateResponse/CustomerOriginUpdateResult/HttpsLoadBalancing' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/faultcode' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'CustomerUserGetResponse/CustomerUserGetResult/Country' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomersGetResponse/CustomersGetResult/Customer/intId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'CustomerAccessModuleUpdate/strCustomId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerCnameAdd/strCredential' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUpdate/strBillingCity' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerCustomIdUpdate/strCredential' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerHttpLargeUpdate/strStatus' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerAccountMeasuredByUpdate/strCredential' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerAccessModuleGetResponse' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomerAccessModuleGetResponse',
               'CustomersGetResponse/CustomersGetResult/Customer/strBillingContactFax' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUserUpdate/strCustomerId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginGetResponse/CustomerOriginGetResult/FullURL' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginAdvancedUpdateResponse/CustomerOriginAdvancedUpdateResult/ShieldPOPs' => 'CDN::Edgecast::Client::auto::Administration::Type::ArrayOfShieldPOP',
               'CustomerUpdate/strBillingContactPhone' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginAdvancedUpdate/strHttpLoadBalMode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerAdd/strBillingContactTitle' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerCnamesGet' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomerCnamesGet',
               'CustomerOriginAdvancedUpdateResponse/CustomerOriginAdvancedUpdateResult/HttpsHostnames/Hostname' => 'CDN::Edgecast::Client::auto::Administration::Type::Hostname',
               'CustomerOriginsGetResponse/CustomerOriginsGetResult/CustomerOrigin/Id' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'CustomerOriginAdvancedAdd/strShieldPopCodes' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginAdd' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomerOriginAdd',
               'CustomerOriginUpdateResponse' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomerOriginUpdateResponse',
               'CustomerUserGetResponse/CustomerUserGetResult/Phone' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginsAdvancedGet/strCustomId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerAdd/strAddress1' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomersGetResponse/CustomersGetResult/Customer/strContactLastName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUpdate/strCredential' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUserUpdate/strCountry' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerAdd/strContactPhone' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginAdvancedUpdate/strHostHeaderValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUserAccessModuleUpdate' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomerUserAccessModuleUpdate',
               'CustomerGetResponse/CustomerGetResult/strState' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginAdvancedGetResponse/CustomerOriginAdvancedGetResult/HttpHostnames/Hostname/IsPrimary' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'CustomerOriginsAdvancedGetResponse/CustomerOriginsAdvancedGetResult/CustomerOriginInfo/HttpHostnames/Hostname/Name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUserGetResponse/CustomerUserGetResult/LastName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUserGetResponse/CustomerUserGetResult/Address1' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerCnameAdd/intOriginId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'CustomerOriginDelete' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomerOriginDelete',
               'CustomerOriginUpdate/strOriginString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'OriginShieldPOPsGetResponse/OriginShieldPOPsGetResult/ShieldPOP' => 'CDN::Edgecast::Client::auto::Administration::Type::ShieldPOP',
               'CustomerUserDelete/intCustomerUserId' => 'SOAP::WSDL::XSD::Typelib::Builtin::unsignedInt',
               'CustomerOriginAdvancedGetResponse/CustomerOriginAdvancedGetResult/HttpHostnames/Hostname' => 'CDN::Edgecast::Client::auto::Administration::Type::Hostname',
               'CustomerOriginUpdateResponse/CustomerOriginUpdateResult/HttpsHostnames/Hostname/IsPrimary' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'CustomerUserAccessModuleGet/strCredential' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerStatusUpdate/strCustomId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUserAccessModuleUpdate/intAccessModuleId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'CustomersGetResponse/CustomersGetResult/Customer' => 'CDN::Edgecast::Client::auto::Administration::Type::Customer',
               'CustomerOriginsAdvancedGetResponse/CustomerOriginsAdvancedGetResult/CustomerOriginInfo/HttpsHostnames/Hostname/Name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginAdvancedUpdateResponse/CustomerOriginAdvancedUpdateResult/MediaTypeId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'CustomerGetResponse/CustomerGetResult/strBillingContactMobile' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUserDeleteResponse' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomerUserDeleteResponse',
               'CustomerOriginsAdvancedGetResponse/CustomerOriginsAdvancedGetResult/CustomerOriginInfo/UseOriginShield' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'CustomerOriginUpdateResponse/CustomerOriginUpdateResult/Id' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'OriginShieldPOPsGetResponse/OriginShieldPOPsGetResult/ShieldPOP/POPCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginUpdateResponse/CustomerOriginUpdateResult/HttpHostnames/Hostname' => 'CDN::Edgecast::Client::auto::Administration::Type::Hostname',
               'CustomerOriginsGetResponse/CustomerOriginsGetResult/CustomerOrigin/FullURL' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomersGetResponse/CustomersGetResult/Customer/strCity' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerGetResponse/CustomerGetResult/strBillingAddress1' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerServiceUpdate/intServiceId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'CustomerOriginUpdateResponse/CustomerOriginUpdateResult/HostHeader' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerCnameAdd/intMediaType' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'CustomerOriginAdvancedAdd/strHostHeaderValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUpdate/strBillingContactFirstName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUsersGetResponse/CustomerUsersGetResult/CustomerUser/Mobile' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUpdate/strBillingContactMobile' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUserAdd/strEmail' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerGetResponse/CustomerGetResult/strBillingCity' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUserUpdate/strEmail' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginsGetResponse/CustomerOriginsGetResult/CustomerOrigin/OriginShield' => 'SOAP::WSDL::XSD::Typelib::Builtin::short',
               'OriginShieldPOPsGetResponse/OriginShieldPOPsGetResult' => 'CDN::Edgecast::Client::auto::Administration::Type::ArrayOfShieldPOP',
               'CustomerAdd/strContactTitle' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUpdate/strZip' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginGet/strCredential' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUpdate/strBillingContactEmail' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginUpdateResponse/CustomerOriginUpdateResult/HttpsFullUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginUpdateResponse/CustomerOriginUpdateResult/HttpFullUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUpdate/strContactPhone' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUserAdd/strAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginUpdateResponse/CustomerOriginUpdateResult/HttpsHostnames' => 'CDN::Edgecast::Client::auto::Administration::Type::ArrayOfHostname',
               'CustomerUserAdd/strLastName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomersGetResponse/CustomersGetResult/Customer/strName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerFmsGetResponse/CustomerFmsGetResult' => 'CDN::Edgecast::Client::auto::Administration::Type::FmsInfo',
               'CustomerUserAccessModuleGet' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomerUserAccessModuleGet',
               'CustomerUserUpdate/strAddress1' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerWmsUpdate/strStatus' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginUpdateResponse/CustomerOriginUpdateResult/HttpsHostnames/Hostname/Ordinal' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'CustomerGetResponse/CustomerGetResult/strAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerHttpGetResponse' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomerHttpGetResponse',
               'CustomerUserUpdate/strPassword' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerGetResponse/CustomerGetResult/strContactEmail' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerHttpSmallUpdate/strCustomId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginsAdvancedGet/strCredential' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerWmsGet/strCustomerId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerCnamesGet/intMediaType' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'CustomerGetResponse/CustomerGetResult/strContactMobile' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUpdate/strAddress1' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerFmsGetResponse' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomerFmsGetResponse',
               'CustomerOriginAdvancedUpdateResponse/CustomerOriginAdvancedUpdateResult/HttpHostnames' => 'CDN::Edgecast::Client::auto::Administration::Type::ArrayOfHostname',
               'CustomerOriginGet/intCustomerOriginId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'CustomerHttpUpdate/strCredential' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUpdate/strAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerHttpUpdate/strStatus' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerCnameAddResponse/CustomerCnameAddResult' => 'SOAP::WSDL::XSD::Typelib::Builtin::unsignedInt',
               'CustomerGet' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomerGet',
               'CustomerGetResponse/CustomerGetResult/strBillingContactPhone' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerAccountMeasuredByGet/strCredential' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerWmsUpdate/strContentURL' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUserGetResponse/CustomerUserGetResult/Address2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUserUpdate/intCustomerUserId' => 'SOAP::WSDL::XSD::Typelib::Builtin::unsignedInt',
               'CustomerUserUpdate/strAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginsAdvancedGetResponse/CustomerOriginsAdvancedGetResult/CustomerOriginInfo/Id' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'CustomerUserAdd/strCustomId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUsersGetResponse/CustomerUsersGetResult/CustomerUser/Title' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerFmsUpdate/strContentURL' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerFmsGetResponse/CustomerFmsGetResult/intStatus' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'CustomerOriginAdvancedAddResponse' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomerOriginAdvancedAddResponse',
               'CustomerOriginAdvancedGetResponse/CustomerOriginAdvancedGetResult/ShieldPOPs/ShieldPOP/Region' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerGetResponse/CustomerGetResult/strAddress1' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUserAdd/strPhone' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginsAdvancedGetResponse/CustomerOriginsAdvancedGetResult/CustomerOriginInfo/HttpsHostnames/Hostname/IsPrimary' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'CustomerStatusGetResponse/CustomerStatusGetResult' => 'SOAP::WSDL::XSD::Typelib::Builtin::short',
               'CustomerGetResponse/CustomerGetResult/strBillingContactFirstName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginAdvancedGet/strCustomerId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerDeliveryRegionUpdate/strCredential' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerServiceUpdate/strCredential' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomersGetResponse/CustomersGetResult' => 'CDN::Edgecast::Client::auto::Administration::Type::Customers',
               'CustomerUsersGetResponse/CustomerUsersGetResult/CustomerUser/Password' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerGetResponse/CustomerGetResult' => 'CDN::Edgecast::Client::auto::Administration::Type::Customer',
               'CustomerUpdate/strBillingContactTitle' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginAdvancedGet/strCustomId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerStatusUpdate/strCredential' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerHttpLargeGet/strCustomId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerCnameAdd/strCustomerId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginAdvancedUpdateResponse/CustomerOriginAdvancedUpdateResult/HttpHostnames/Hostname/Ordinal' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'CustomerOriginUpdate/strOriginShield' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerHttpSmallGetResponse/CustomerHttpSmallGetResult' => 'CDN::Edgecast::Client::auto::Administration::Type::HttpSmallInfo',
               'CustomerAccessModuleUpdateResponse' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomerAccessModuleUpdateResponse',
               'CustomerUserAccessModuleUpdate/strCustomerId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginAdvancedUpdateResponse/CustomerOriginAdvancedUpdateResult/UseOriginShield' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'CustomerAdd/strBillingAddress1' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUserUpdate/strLastName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerCnamesGetResponse' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomerCnamesGetResponse',
               'CustomerAdd/strCountry' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUserGet/strCustomId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerGetResponse/CustomerGetResult/strContactFirstName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginGetResponse/CustomerOriginGetResult/MediaTypeId' => 'SOAP::WSDL::XSD::Typelib::Builtin::short',
               'Fault' => 'SOAP::WSDL::SOAP::Typelib::Fault11',
               'CustomerHttpGet' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomerHttpGet',
               'CustomerOriginUpdate/strCustomId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomersGetResponse/CustomersGetResult/Customer/strContactMobile' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerCnameGet/intCustomerCnameId' => 'SOAP::WSDL::XSD::Typelib::Builtin::unsignedInt',
               'CustomersGetResponse/CustomersGetResult/Customer/strContactPhone' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomersGetResponse/CustomersGetResult/Customer/strBillingCountry' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomersGetResponse/CustomersGetResult/Customer/strBillingZip' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginDeleteResponse' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomerOriginDeleteResponse',
               'CustomerHttpLargeUpdateResponse/CustomerHttpLargeUpdateResult' => 'SOAP::WSDL::XSD::Typelib::Builtin::short',
               'CustomerOriginAdd/intMediaType' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'CustomerCnameDeleteResponse/CustomerCnameDeleteResult' => 'SOAP::WSDL::XSD::Typelib::Builtin::short',
               'CustomerStatusGet' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomerStatusGet',
               'CustomerOriginAdvancedUpdate/strCustomId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUpdate/strBillingContactLastName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUserAdd/strZip' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerHttpUpdate' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomerHttpUpdate',
               'CustomerFmsUpdate/strCustomId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUserGetResponse/CustomerUserGetResult/Zip' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerAccountMeasuredByUpdate/strCustomId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerAccountMeasuredByGet/strCustomId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUserAccessModuleGetResponse' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomerUserAccessModuleGetResponse',
               'CustomerUserAdd/strCity' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUpdate/strState' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerAdd/strBillingAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerWmsGet' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomerWmsGet',
               'CustomerGetResponse/CustomerGetResult/strBillingZip' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerCustomIdUpdateResponse/CustomerCustomIdUpdateResult' => 'SOAP::WSDL::XSD::Typelib::Builtin::short',
               'CustomerUserAdd/strAddress1' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginsGet/strCredential' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerHttpLargeUpdate/strCredential' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerGetResponse/CustomerGetResult/strCustomId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginsAdvancedGetResponse/CustomerOriginsAdvancedGetResult/CustomerOriginInfo/MediaTypeId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'CustomerUserUpdate/strMobile' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUserGetResponse' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomerUserGetResponse',
               'CustomerAdd/strBillingState' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUsersGetResponse' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomerUsersGetResponse',
               'CustomerStatusUpdate/intStatus' => 'SOAP::WSDL::XSD::Typelib::Builtin::short',
               'CustomerHttpLargeGetResponse/CustomerHttpLargeGetResult' => 'CDN::Edgecast::Client::auto::Administration::Type::HttpInfo',
               'CustomerUrlUpdate/strCredential' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUserAccessModuleUpdate/intCustomerUserId' => 'SOAP::WSDL::XSD::Typelib::Builtin::unsignedInt',
               'CustomerHttpGet/strCustomerId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginAdvancedGetResponse/CustomerOriginAdvancedGetResult/UseOriginShield' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'CustomerHttpSmallGet/strCustomerId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomersGetResponse/CustomersGetResult/Customer/strBillingContactEmail' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUserUpdateResponse/CustomerUserUpdateResult' => 'SOAP::WSDL::XSD::Typelib::Builtin::short',
               'CustomerUpdate/strCity' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginAdvancedUpdate/strHttpHostnames' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomersGetResponse/CustomersGetResult/Customer/strAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerFmsGet' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomerFmsGet',
               'CustomerOriginAdvancedUpdateResponse/CustomerOriginAdvancedUpdateResult/ShieldPOPs/ShieldPOP/Name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUserDelete' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomerUserDelete',
               'CustomerAccessModuleUpdate' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomerAccessModuleUpdate',
               'CustomerOriginAdd/strCredential' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUserUpdate/strTimeZoneId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerHttpLargeUpdate/strCustomerId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomersGetResponse/CustomersGetResult/Customer/strCountry' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerWmsGet/strCredential' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerWmsGetResponse' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomerWmsGetResponse',
               'OriginShieldPOPsGetResponse/OriginShieldPOPsGetResult/ShieldPOP/Name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerCnameDelete/strCustomerId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUserAdd/strCustomerId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerGetResponse/CustomerGetResult/strWebsite' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginGet/strCustomerId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUpdate/strBillingAddress2' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUserUpdate/strFax' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerAccountMeasuredByUpdateResponse' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomerAccountMeasuredByUpdateResponse',
               'CustomerUsersGet/strCredential' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginsAdvancedGetResponse/CustomerOriginsAdvancedGetResult/CustomerOriginInfo/HttpsFullUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUsersGetResponse/CustomerUsersGetResult/CustomerUser/LastName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerFmsGet/strCustomerId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginsGetResponse/CustomerOriginsGetResult/CustomerOrigin' => 'CDN::Edgecast::Client::auto::Administration::Type::CustomerOrigin',
               'CustomerUserGetResponse/CustomerUserGetResult/State' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUserAccessModuleGet/intCustomerUserId' => 'SOAP::WSDL::XSD::Typelib::Builtin::unsignedInt',
               'CustomerUserUpdate/strPhone' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUserUpdate/strState' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerCnameGetResponse/CustomerCnameGetResult/Id' => 'SOAP::WSDL::XSD::Typelib::Builtin::unsignedInt',
               'CustomersGetResponse/CustomersGetResult/Customer/strBillingContactFirstName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerAdd/strZip' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerServiceUpdate/strCustomId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginsGetResponse/CustomerOriginsGetResult' => 'CDN::Edgecast::Client::auto::Administration::Type::CustomerOrigins',
               'CustomerAdd/strWebsite' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerHttpUpdate/strCustomId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUserGetResponse/CustomerUserGetResult/Password' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginAdvancedUpdateResponse/CustomerOriginAdvancedUpdateResult/HttpsFullUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerCnameGet/strCustomId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUpdate/strContactFax' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerAdd/intStatus' => 'SOAP::WSDL::XSD::Typelib::Builtin::unsignedInt',
               'CustomerOriginGetResponse/CustomerOriginGetResult/DiskStorageLocation' => 'SOAP::WSDL::XSD::Typelib::Builtin::short',
               'CustomerOriginsAdvancedGetResponse/CustomerOriginsAdvancedGetResult/CustomerOriginInfo/HttpHostnames' => 'CDN::Edgecast::Client::auto::Administration::Type::ArrayOfHostname',
               'CustomerUpdate/strContactMobile' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerAccessModuleUpdate/intStatus' => 'SOAP::WSDL::XSD::Typelib::Builtin::short',
               'OriginShieldPOPsGetResponse' => 'CDN::Edgecast::Client::auto::Administration::Element::OriginShieldPOPsGetResponse',
               'CustomersGetResponse/CustomersGetResult/Customer/intStatus' => 'SOAP::WSDL::XSD::Typelib::Builtin::short',
               'CustomerHttpLargeUpdate/strContentURL' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerStatusUpdate' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomerStatusUpdate',
               'CustomerUpdate/strCustomerId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerGetResponse/CustomerGetResult/intStatus' => 'SOAP::WSDL::XSD::Typelib::Builtin::short',
               'CustomerOriginAdd/strOriginShield' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerCnameDeleteResponse' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomerCnameDeleteResponse',
               'CustomerOriginAdvancedAdd' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomerOriginAdvancedAdd',
               'CustomerCnameAdd/strDirPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginUpdateResponse/CustomerOriginUpdateResult/HttpHostnames/Hostname/IsPrimary' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'CustomerGetResponse/CustomerGetResult/strBillingState' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerFmsGet/strCredential' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerAccessModuleGet/strCustomId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerAdd/strBillingContactFirstName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerHttpLargeGetResponse' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomerHttpLargeGetResponse',
               'CustomerOriginAdvancedUpdateResponse/CustomerOriginAdvancedUpdateResult/HttpsHostnames/Hostname/Ordinal' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'CustomerOriginsGet/strCustomerId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerAdd/strBillingContactMobile' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUsersGetResponse/CustomerUsersGetResult/CustomerUser/Phone' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerHttpLargeGet/strCredential' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginsAdvancedGetResponse/CustomerOriginsAdvancedGetResult/CustomerOriginInfo/DirectoryName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerAdd/strBillingCountry' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerAccountMeasuredByUpdateResponse/CustomerAccountMeasuredByUpdateResult' => 'SOAP::WSDL::XSD::Typelib::Builtin::short',
               'CustomerDeliveryRegionUpdate/intDeliveryRegionId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'CustomerUserAddResponse' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomerUserAddResponse',
               'CustomerWmsUpdateResponse/CustomerWmsUpdateResult' => 'SOAP::WSDL::XSD::Typelib::Builtin::short',
               'CustomerAdd/strCredential' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginsAdvancedGetResponse/CustomerOriginsAdvancedGetResult/CustomerOriginInfo/ShieldPOPs' => 'CDN::Edgecast::Client::auto::Administration::Type::ArrayOfShieldPOP',
               'CustomersGetResponse/CustomersGetResult/Customer/strBillingContactMobile' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginsAdvancedGetResponse/CustomerOriginsAdvancedGetResult/CustomerOriginInfo/HostHeader' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUserGetResponse/CustomerUserGetResult/FirstName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginAdd/strCustomId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUserGetResponse/CustomerUserGetResult/Mobile' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomersGetResponse/CustomersGetResult/Customer/strBillingState' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerCnameAdd' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomerCnameAdd',
               'CustomerUserUpdateResponse' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomerUserUpdateResponse',
               'CustomerUserUpdate' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomerUserUpdate',
               'CustomerFmsUpdate/strCredential' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerDelete/strCustomId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerAccessModuleUpdateResponse/CustomerAccessModuleUpdateResult' => 'SOAP::WSDL::XSD::Typelib::Builtin::short',
               'CustomerHttpLargeGet/strCustomerId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUpdate/strBillingAddress1' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerAdd/strContactMobile' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerCnameGetResponse/CustomerCnameGetResult' => 'CDN::Edgecast::Client::auto::Administration::Type::CustomerCname',
               'CustomerUsersGetResponse/CustomerUsersGetResult/CustomerUser/City' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUsersGet' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomerUsersGet',
               'CustomerUsersGetResponse/CustomerUsersGetResult/CustomerUser/Address1' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'DeliveryRegionsGet/strCredential' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomersGetResponse/CustomersGetResult/Customer/strState' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUserAccessModuleGetResponse/CustomerUserAccessModuleGetResult' => 'SOAP::WSDL::XSD::Typelib::Builtin::short',
               'CustomerUserAdd/strTitle' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerGetResponse/CustomerGetResult/strBillingContactFax' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginAddResponse/CustomerOriginAddResult' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'CustomerUserAdd/strFirstName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginAdvancedGetResponse/CustomerOriginAdvancedGetResult/HttpsHostnames/Hostname/Name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerWmsGetResponse/CustomerWmsGetResult/intStatus' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'CustomerHttpUpdateResponse' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomerHttpUpdateResponse',
               'CustomerDeleteResponse' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomerDeleteResponse',
               'CustomerOriginUpdateResponse/CustomerOriginUpdateResult/UseOriginShield' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'CustomerServiceUpdateResponse/CustomerServiceUpdateResult' => 'SOAP::WSDL::XSD::Typelib::Builtin::short',
               'CustomerUrlUpdateResponse/CustomerUrlUpdateResult' => 'SOAP::WSDL::XSD::Typelib::Builtin::short',
               'CustomerOriginAdvancedGet/intCustomerOriginId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'CustomerOriginsAdvancedGetResponse/CustomerOriginsAdvancedGetResult/CustomerOriginInfo/HttpsHostnames/Hostname/Ordinal' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'CustomerUsersGetResponse/CustomerUsersGetResult/CustomerUser/FirstName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerFmsGet/strCustomId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerCnamesGetResponse/CustomerCnamesGetResult/CustomerCname/Cname' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerHttpGetResponse/CustomerHttpGetResult/strContentURL' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerFmsUpdate/strStatus' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerCnameDelete/strCustomId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerCnameGetResponse/CustomerCnameGetResult/PointsTo' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginUpdate/strCredential' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerCnameGet' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomerCnameGet',
               'CustomerUsersGetResponse/CustomerUsersGetResult/CustomerUser' => 'CDN::Edgecast::Client::auto::Administration::Type::CustomerUser',
               'CustomerOriginAdvancedUpdateResponse/CustomerOriginAdvancedUpdateResult/HttpsHostnames/Hostname/IsPrimary' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'CustomerUserGetResponse/CustomerUserGetResult/City' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginsGetResponse/CustomerOriginsGetResult/CustomerOrigin/OriginString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerDeliveryRegionUpdateResponse' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomerDeliveryRegionUpdateResponse',
               'CustomerOriginsAdvancedGetResponse/CustomerOriginsAdvancedGetResult/CustomerOriginInfo/ShieldPOPs/ShieldPOP/Name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerCustomIdUpdateResponse' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomerCustomIdUpdateResponse',
               'CustomerOriginAdvancedAdd/strCustomId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerGetResponse/CustomerGetResult/strCountry' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/faultactor' => 'SOAP::WSDL::XSD::Typelib::Builtin::token',
               'CustomerAccountMeasuredByUpdate/strCustomerId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginsGetResponse/CustomerOriginsGetResult/CustomerOrigin/MediaTypeId' => 'SOAP::WSDL::XSD::Typelib::Builtin::short',
               'CustomerOriginAdvancedUpdate/strCredential' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginsAdvancedGet/strCustomerId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerAccountMeasuredByGet' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomerAccountMeasuredByGet',
               'CustomerUsersGetResponse/CustomerUsersGetResult/CustomerUser/Country' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUpdate/strBillingCountry' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerServiceUpdateResponse' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomerServiceUpdateResponse',
               'CustomerGetResponse/CustomerGetResult/strContactTitle' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUserUpdate/strTitle' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUserAdd/strMobile' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerCustomIdUpdate/strCustomerId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUserAdd/strIsAdmin' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerHttpGet/strCredential' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerCnameDelete' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomerCnameDelete',
               'CustomerGetResponse/CustomerGetResult/strBillingCountry' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerStatusGetResponse' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomerStatusGetResponse',
               'CustomerOriginsAdvancedGetResponse/CustomerOriginsAdvancedGetResult/CustomerOriginInfo/HttpsLoadBalancing' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerGet/strCustomerId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerStatusUpdate/strCustomerId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerCnamesGet/strCredential' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUserUpdate/strCredential' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerDeliveryRegionUpdateResponse/CustomerDeliveryRegionUpdateResult' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'CustomerStatusUpdateResponse/CustomerStatusUpdateResult' => 'SOAP::WSDL::XSD::Typelib::Builtin::short',
               'CustomerOriginAdvancedUpdateResponse/CustomerOriginAdvancedUpdateResult/HostHeader' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerAdd/strBillingZip' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerHttpGetResponse/CustomerHttpGetResult' => 'CDN::Edgecast::Client::auto::Administration::Type::HttpInfo',
               'OriginShieldPOPsGet/strCredential' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerDeliveryRegionUpdate/strCustomerId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginsAdvancedGetResponse/CustomerOriginsAdvancedGetResult/CustomerOriginInfo/HttpFullUrl' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginDelete/strCustomerId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginsAdvancedGetResponse' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomerOriginsAdvancedGetResponse',
               'CustomerOriginUpdate/strCustomerId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginUpdateResponse/CustomerOriginUpdateResult/ShieldPOPs/ShieldPOP/Name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerCnamesGetResponse/CustomerCnamesGetResult' => 'CDN::Edgecast::Client::auto::Administration::Type::CustomerCnames',
               'DeliveryRegionsGetResponse/DeliveryRegionsGetResult' => 'CDN::Edgecast::Client::auto::Administration::Type::ArrayOfDeliveryRegion',
               'CustomerGetResponse/CustomerGetResult/strBillingContactEmail' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerAdd/strBillingContactPhone' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerHttpLargeUpdateResponse' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomerHttpLargeUpdateResponse',
               'CustomerOriginUpdateResponse/CustomerOriginUpdateResult/HttpsHostnames/Hostname' => 'CDN::Edgecast::Client::auto::Administration::Type::Hostname',
               'CustomerUserAdd/strPassword' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerAccountMeasuredByGetResponse/CustomerAccountMeasuredByGetResult' => 'SOAP::WSDL::XSD::Typelib::Builtin::short',
               'CustomerCnamesGetResponse/CustomerCnamesGetResult/CustomerCname/OriginId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'CustomerUpdate/strWebsite' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginGetResponse/CustomerOriginGetResult/OriginString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomersGetResponse/CustomersGetResult/Customer/strZip' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginsAdvancedGetResponse/CustomerOriginsAdvancedGetResult' => 'CDN::Edgecast::Client::auto::Administration::Type::ArrayOfCustomerOriginInfo',
               'CustomerOriginAdvancedGet/strCredential' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerGet/strCredential' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginAdvancedGetResponse/CustomerOriginAdvancedGetResult/HttpsHostnames/Hostname/Ordinal' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'CustomerUserAddResponse/CustomerUserAddResult' => 'SOAP::WSDL::XSD::Typelib::Builtin::unsignedInt',
               'CustomerOriginAdvancedGet' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomerOriginAdvancedGet',
               'CustomerUsersGetResponse/CustomerUsersGetResult/CustomerUser/IsAdmin' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'CustomerOriginAdvancedAddResponse/CustomerOriginAdvancedAddResult' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'CustomerOriginAdvancedGetResponse/CustomerOriginAdvancedGetResult/HttpsHostnames' => 'CDN::Edgecast::Client::auto::Administration::Type::ArrayOfHostname',
               'CustomerUserDeleteResponse/CustomerUserDeleteResult' => 'SOAP::WSDL::XSD::Typelib::Builtin::short',
               'CustomerOriginAdvancedUpdateResponse/CustomerOriginAdvancedUpdateResult/HttpsHostnames/Hostname/Name' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerCnameDelete/strCredential' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUrlUpdate/strCustomId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginsAdvancedGet/intMediaType' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'CustomerServiceUpdate' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomerServiceUpdate',
               'CustomerGetResponse/CustomerGetResult/strNotes' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginAdvancedAdd/strDirName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerHttpSmallUpdateResponse/CustomerHttpSmallUpdateResult' => 'SOAP::WSDL::XSD::Typelib::Builtin::short',
               'DeliveryRegionsGetResponse/DeliveryRegionsGetResult/DeliveryRegion' => 'CDN::Edgecast::Client::auto::Administration::Type::DeliveryRegion',
               'CustomerOriginAdvancedAdd/strHttpsHostnames' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerFmsUpdate' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomerFmsUpdate',
               'CustomerOriginsAdvancedGet' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomerOriginsAdvancedGet',
               'CustomerAccountMeasuredByUpdate' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomerAccountMeasuredByUpdate',
               'CustomerCnameGetResponse/CustomerCnameGetResult/Cname' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginsGetResponse/CustomerOriginsGetResult/CustomerOrigin/DiskStorageLocationName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerHttpSmallGetResponse' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomerHttpSmallGetResponse',
               'CustomerOriginUpdate/intCustomerOriginId' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'CustomerWmsUpdate/strCredential' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUserAdd' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomerUserAdd',
               'CustomerOriginUpdateResponse/CustomerOriginUpdateResult/ShieldPOPs/ShieldPOP/POPCode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerHttpLargeGetResponse/CustomerHttpLargeGetResult/intStatus' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'CustomerFmsGetResponse/CustomerFmsGetResult/strContentURL' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginAdvancedUpdateResponse/CustomerOriginAdvancedUpdateResult/HttpLoadBalancing' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerDeliveryRegionUpdate' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomerDeliveryRegionUpdate',
               'CustomerUpdate/strCustomId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUserAccessModuleUpdateResponse/CustomerUserAccessModuleUpdateResult' => 'SOAP::WSDL::XSD::Typelib::Builtin::short',
               'CustomersGetResponse/CustomersGetResult/Customer/strBillingContactPhone' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUserUpdate/strCustomId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginAdvancedUpdate/strHttpsLoadBalMode' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerOriginsAdvancedGetResponse/CustomerOriginsAdvancedGetResult/CustomerOriginInfo/HttpLoadBalancing' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUserGetResponse/CustomerUserGetResult' => 'CDN::Edgecast::Client::auto::Administration::Type::CustomerUser',
               'CustomerUserAccessModuleUpdate/strCredential' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerDelete/strCustomerId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerFmsUpdateResponse' => 'CDN::Edgecast::Client::auto::Administration::Element::CustomerFmsUpdateResponse',
               'CustomersGetResponse/CustomersGetResult/Customer/strHex' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerAdd/strState' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'CustomerUserGet/strCredential' => 'SOAP::WSDL::XSD::Typelib::Builtin::string'
             };
;

sub get_class {
  my $name = join '/', @{ $_[1] };
  return $typemap_1->{ $name };
}

sub get_typemap {
    return $typemap_1;
}

1;

__END__

__END__

=pod

=head1 NAME

CDN::Edgecast::Client::auto::Administration::Typemap::EdgeCastWebServices - typemap for EdgeCastWebServices

=head1 VERSION

version 0.01.00

=head1 DESCRIPTION

Typemap created by SOAP::WSDL for map-based SOAP message parsers.

=cut