package CDN::Edgecast::Client::auto::Administration::Type::Customers;
BEGIN {
  $CDN::Edgecast::Client::auto::Administration::Type::Customers::VERSION = '0.01.00';
}
use strict;
use warnings;


__PACKAGE__->_set_element_form_qualified(1);

sub get_xmlns { 'EC:WebServices' };

our $XML_ATTRIBUTE_CLASS;
undef $XML_ATTRIBUTE_CLASS;

sub __get_attr_class {
    return $XML_ATTRIBUTE_CLASS;
}

use Class::Std::Fast::Storable constructor => 'none';
use base qw(SOAP::WSDL::XSD::Typelib::ComplexType);

Class::Std::initialize();

{ # BLOCK to scope variables

my %Customer_of :ATTR(:get<Customer>);

__PACKAGE__->_factory(
    [ qw(        Customer

    ) ],
    {
        'Customer' => \%Customer_of,
    },
    {
        'Customer' => 'CDN::Edgecast::Client::auto::Administration::Type::Customer',
    },
    {

        'Customer' => 'Customer',
    }
);

} # end BLOCK







1;


=pod

=head1 NAME

CDN::Edgecast::Client::auto::Administration::Type::Customers

=head1 VERSION

version 0.01.00

=head1 DESCRIPTION

Perl data type class for the XML Schema defined complexType
Customers from the namespace EC:WebServices.






=head2 PROPERTIES

The following properties may be accessed using get_PROPERTY / set_PROPERTY
methods:

=over

=item * Customer




=back


=head1 METHODS

=head2 new

Constructor. The following data structure may be passed to new():

 { # CDN::Edgecast::Client::auto::Administration::Type::Customers
   Customer =>  { # CDN::Edgecast::Client::auto::Administration::Type::Customer
     intId =>  $some_value, # int
     strHex =>  $some_value, # string
     strName =>  $some_value, # string
     strCustomId =>  $some_value, # string
     intStatus =>  $some_value, # short
     strWebsite =>  $some_value, # string
     strAddress1 =>  $some_value, # string
     strAddress2 =>  $some_value, # string
     strCity =>  $some_value, # string
     strState =>  $some_value, # string
     strZip =>  $some_value, # string
     strCountry =>  $some_value, # string
     strBillingAddress1 =>  $some_value, # string
     strBillingAddress2 =>  $some_value, # string
     strBillingCity =>  $some_value, # string
     strBillingState =>  $some_value, # string
     strBillingZip =>  $some_value, # string
     strBillingCountry =>  $some_value, # string
     strNotes =>  $some_value, # string
     strContactFirstName =>  $some_value, # string
     strContactLastName =>  $some_value, # string
     strContactTitle =>  $some_value, # string
     strContactEmail =>  $some_value, # string
     strContactPhone =>  $some_value, # string
     strContactFax =>  $some_value, # string
     strContactMobile =>  $some_value, # string
     strBillingContactFirstName =>  $some_value, # string
     strBillingContactLastName =>  $some_value, # string
     strBillingContactTitle =>  $some_value, # string
     strBillingContactEmail =>  $some_value, # string
     strBillingContactPhone =>  $some_value, # string
     strBillingContactFax =>  $some_value, # string
     strBillingContactMobile =>  $some_value, # string
   },
 },




=head1 AUTHOR

Generated by SOAP::WSDL

=cut